==> openshift-model-config-6.3.0-sources.jar: io/fabric8/openshift/api/model/config/v1/PowerVSPlatformStatusFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PowerVSPlatformStatusFluentImpl<A extends PowerVSPlatformStatusFluent<A>> extends BaseFluent<A> implements PowerVSPlatformStatusFluent<A>{
  public PowerVSPlatformStatusFluentImpl() {
  }
  public PowerVSPlatformStatusFluentImpl(PowerVSPlatformStatus instance) {
    this.withCisInstanceCRN(instance.getCisInstanceCRN()); 
    this.withRegion(instance.getRegion()); 
    this.withServiceEndpoints(instance.getServiceEndpoints()); 
    this.withZone(instance.getZone()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String cisInstanceCRN;
  private String region;
  private ArrayList<PowerVSServiceEndpointBuilder> serviceEndpoints = new ArrayList<PowerVSServiceEndpointBuilder>();
  private String zone;
  private Map<String,Object> additionalProperties;
  public String getCisInstanceCRN() {
    return this.cisInstanceCRN;
  }
  public A withCisInstanceCRN(String cisInstanceCRN) {
    this.cisInstanceCRN=cisInstanceCRN; return (A) this;
  }
  public Boolean hasCisInstanceCRN() {
    return this.cisInstanceCRN != null;
  }
  public String getRegion() {
    return this.region;
  }
  public A withRegion(String region) {
    this.region=region; return (A) this;
  }
  public Boolean hasRegion() {
    return this.region != null;
  }
  public A addToServiceEndpoints(Integer index,PowerVSServiceEndpoint item) {
    if (this.serviceEndpoints == null) {this.serviceEndpoints = new ArrayList<PowerVSServiceEndpointBuilder>();}
    PowerVSServiceEndpointBuilder builder = new PowerVSServiceEndpointBuilder(item);_visitables.get("serviceEndpoints").add(index >= 0 ? index : _visitables.get("serviceEndpoints").size(), builder);this.serviceEndpoints.add(index >= 0 ? index : serviceEndpoints.size(), builder); return (A)this;
  }
  public A setToServiceEndpoints(Integer index,PowerVSServiceEndpoint item) {
    if (this.serviceEndpoints == null) {this.serviceEndpoints = new ArrayList<PowerVSServiceEndpointBuilder>();}
    PowerVSServiceEndpointBuilder builder = new PowerVSServiceEndpointBuilder(item);
    if (index < 0 || index >= _visitables.get("serviceEndpoints").size()) { _visitables.get("serviceEndpoints").add(builder); } else { _visitables.get("serviceEndpoints").set(index, builder);}
    if (index < 0 || index >= serviceEndpoints.size()) { serviceEndpoints.add(builder); } else { serviceEndpoints.set(index, builder);}
     return (A)this;
  }
  public A addToServiceEndpoints(io.fabric8.openshift.api.model.config.v1.PowerVSServiceEndpoint... items) {
    if (this.serviceEndpoints == null) {this.serviceEndpoints = new ArrayList<PowerVSServiceEndpointBuilder>();}
    for (PowerVSServiceEndpoint item : items) {PowerVSServiceEndpointBuilder builder = new PowerVSServiceEndpointBuilder(item);_visitables.get("serviceEndpoints").add(builder);this.serviceEndpoints.add(builder);} return (A)this;
  }
  public A addAllToServiceEndpoints(Collection<PowerVSServiceEndpoint> items) {
    if (this.serviceEndpoints == null) {this.serviceEndpoints = new ArrayList<PowerVSServiceEndpointBuilder>();}
    for (PowerVSServiceEndpoint item : items) {PowerVSServiceEndpointBuilder builder = new PowerVSServiceEndpointBuilder(item);_visitables.get("serviceEndpoints").add(builder);this.serviceEndpoints.add(builder);} return (A)this;
  }
  public A removeFromServiceEndpoints(io.fabric8.openshift.api.model.config.v1.PowerVSServiceEndpoint... items) {
    for (PowerVSServiceEndpoint item : items) {PowerVSServiceEndpointBuilder builder = new PowerVSServiceEndpointBuilder(item);_visitables.get("serviceEndpoints").remove(builder);if (this.serviceEndpoints != null) {this.serviceEndpoints.remove(builder);}} return (A)this;
  }
  public A removeAllFromServiceEndpoints(Collection<PowerVSServiceEndpoint> items) {
    for (PowerVSServiceEndpoint item : items) {PowerVSServiceEndpointBuilder builder = new PowerVSServiceEndpointBuilder(item);_visitables.get("serviceEndpoints").remove(builder);if (this.serviceEndpoints != null) {this.serviceEndpoints.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromServiceEndpoints(Predicate<PowerVSServiceEndpointBuilder> predicate) {
    if (serviceEndpoints == null) return (A) this;
    final Iterator<PowerVSServiceEndpointBuilder> each = serviceEndpoints.iterator();
    final List visitables = _visitables.get("serviceEndpoints");
    while (each.hasNext()) {
      PowerVSServiceEndpointBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildServiceEndpoints instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<PowerVSServiceEndpoint> getServiceEndpoints() {
    return serviceEndpoints != null ? build(serviceEndpoints) : null;
  }
  public List<PowerVSServiceEndpoint> buildServiceEndpoints() {
    return serviceEndpoints != null ? build(serviceEndpoints) : null;
  }
  public PowerVSServiceEndpoint buildServiceEndpoint(Integer index) {
    return this.serviceEndpoints.get(index).build();
  }
  public PowerVSServiceEndpoint buildFirstServiceEndpoint() {
    return this.serviceEndpoints.get(0).build();
  }
  public PowerVSServiceEndpoint buildLastServiceEndpoint() {
    return this.serviceEndpoints.get(serviceEndpoints.size() - 1).build();
  }
  public PowerVSServiceEndpoint buildMatchingServiceEndpoint(Predicate<PowerVSServiceEndpointBuilder> predicate) {
    for (PowerVSServiceEndpointBuilder item: serviceEndpoints) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingServiceEndpoint(Predicate<PowerVSServiceEndpointBuilder> predicate) {
    for (PowerVSServiceEndpointBuilder item: serviceEndpoints) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withServiceEndpoints(List<PowerVSServiceEndpoint> serviceEndpoints) {
    if (this.serviceEndpoints != null) { _visitables.get("serviceEndpoints").removeAll(this.serviceEndpoints);}
    if (serviceEndpoints != null) {this.serviceEndpoints = new ArrayList(); for (PowerVSServiceEndpoint item : serviceEndpoints){this.addToServiceEndpoints(item);}} else { this.serviceEndpoints = null;} return (A) this;
  }
  public A withServiceEndpoints(io.fabric8.openshift.api.model.config.v1.PowerVSServiceEndpoint... serviceEndpoints) {
    if (this.serviceEndpoints != null) {this.serviceEndpoints.clear();}
    if (serviceEndpoints != null) {for (PowerVSServiceEndpoint item :serviceEndpoints){ this.addToServiceEndpoints(item);}} return (A) this;
  }
  public Boolean hasServiceEndpoints() {
    return serviceEndpoints != null && !serviceEndpoints.isEmpty();
  }
  public A addNewServiceEndpoint(String name,String url) {
    return (A)addToServiceEndpoints(new PowerVSServiceEndpoint(name, url));
  }
  public PowerVSPlatformStatusFluent.ServiceEndpointsNested<A> addNewServiceEndpoint() {
    return new PowerVSPlatformStatusFluentImpl.ServiceEndpointsNestedImpl();
  }
  public PowerVSPlatformStatusFluent.ServiceEndpointsNested<A> addNewServiceEndpointLike(PowerVSServiceEndpoint item) {
    return new PowerVSPlatformStatusFluentImpl.ServiceEndpointsNestedImpl(-1, item);
  }
  public PowerVSPlatformStatusFluent.ServiceEndpointsNested<A> setNewServiceEndpointLike(Integer index,PowerVSServiceEndpoint item) {
    return new PowerVSPlatformStatusFluentImpl.ServiceEndpointsNestedImpl(index, item);
  }
  public PowerVSPlatformStatusFluent.ServiceEndpointsNested<A> editServiceEndpoint(Integer index) {
    if (serviceEndpoints.size() <= index) throw new RuntimeException("Can't edit serviceEndpoints. Index exceeds size.");
    return setNewServiceEndpointLike(index, buildServiceEndpoint(index));
  }
  public PowerVSPlatformStatusFluent.ServiceEndpointsNested<A> editFirstServiceEndpoint() {
    if (serviceEndpoints.size() == 0) throw new RuntimeException("Can't edit first serviceEndpoints. The list is empty.");
    return setNewServiceEndpointLike(0, buildServiceEndpoint(0));
  }
  public PowerVSPlatformStatusFluent.ServiceEndpointsNested<A> editLastServiceEndpoint() {
    int index = serviceEndpoints.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last serviceEndpoints. The list is empty.");
    return setNewServiceEndpointLike(index, buildServiceEndpoint(index));
  }
  public PowerVSPlatformStatusFluent.ServiceEndpointsNested<A> editMatchingServiceEndpoint(Predicate<PowerVSServiceEndpointBuilder> predicate) {
    int index = -1;
    for (int i=0;i<serviceEndpoints.size();i++) { 
    if (predicate.test(serviceEndpoints.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching serviceEndpoints. No match found.");
    return setNewServiceEndpointLike(index, buildServiceEndpoint(index));
  }
  public String getZone() {
    return this.zone;
  }
  public A withZone(String zone) {
    this.zone=zone; return (A) this;
  }
  public Boolean hasZone() {
    return this.zone != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PowerVSPlatformStatusFluentImpl that = (PowerVSPlatformStatusFluentImpl) o;
    if (cisInstanceCRN != null ? !cisInstanceCRN.equals(that.cisInstanceCRN) :that.cisInstanceCRN != null) return false;
    if (region != null ? !region.equals(that.region) :that.region != null) return false;
    if (serviceEndpoints != null ? !serviceEndpoints.equals(that.serviceEndpoints) :that.serviceEndpoints != null) return false;
    if (zone != null ? !zone.equals(that.zone) :that.zone != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(cisInstanceCRN,  region,  serviceEndpoints,  zone,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (cisInstanceCRN != null) { sb.append("cisInstanceCRN:"); sb.append(cisInstanceCRN + ","); }
    if (region != null) { sb.append("region:"); sb.append(region + ","); }
    if (serviceEndpoints != null && !serviceEndpoints.isEmpty()) { sb.append("serviceEndpoints:"); sb.append(serviceEndpoints + ","); }
    if (zone != null) { sb.append("zone:"); sb.append(zone + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ServiceEndpointsNestedImpl<N> extends PowerVSServiceEndpointFluentImpl<PowerVSPlatformStatusFluent.ServiceEndpointsNested<N>> implements PowerVSPlatformStatusFluent.ServiceEndpointsNested<N>,Nested<N>{
    ServiceEndpointsNestedImpl(Integer index,PowerVSServiceEndpoint item) {
      this.index = index;
      this.builder = new PowerVSServiceEndpointBuilder(this, item);
    }
    ServiceEndpointsNestedImpl() {
      this.index = -1;
      this.builder = new PowerVSServiceEndpointBuilder(this);
    }
    PowerVSServiceEndpointBuilder builder;
    Integer index;
    public N and() {
      return (N) PowerVSPlatformStatusFluentImpl.this.setToServiceEndpoints(index,builder.build());
    }
    public N endServiceEndpoint() {
      return and();
    }
    
  }
  
}

==> openshift-model-config-6.7.0-sources.jar: io/fabric8/openshift/api/model/config/v1/PowerVSPlatformStatusFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PowerVSPlatformStatusFluentImpl<A extends PowerVSPlatformStatusFluent<A>> extends BaseFluent<A> implements PowerVSPlatformStatusFluent<A>{
  public PowerVSPlatformStatusFluentImpl() {
  }
  public PowerVSPlatformStatusFluentImpl(PowerVSPlatformStatus instance) {
    if (instance != null) {
      this.withCisInstanceCRN(instance.getCisInstanceCRN());
      this.withRegion(instance.getRegion());
      this.withServiceEndpoints(instance.getServiceEndpoints());
      this.withZone(instance.getZone());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String cisInstanceCRN;
  private String region;
  private ArrayList<PowerVSServiceEndpointBuilder> serviceEndpoints = new ArrayList<PowerVSServiceEndpointBuilder>();
  private String zone;
  private Map<String,Object> additionalProperties;
  public String getCisInstanceCRN() {
    return this.cisInstanceCRN;
  }
  public A withCisInstanceCRN(String cisInstanceCRN) {
    this.cisInstanceCRN=cisInstanceCRN; return (A) this;
  }
  public Boolean hasCisInstanceCRN() {
    return this.cisInstanceCRN != null;
  }
  public String getRegion() {
    return this.region;
  }
  public A withRegion(String region) {
    this.region=region; return (A) this;
  }
  public Boolean hasRegion() {
    return this.region != null;
  }
  public A addToServiceEndpoints(int index,PowerVSServiceEndpoint item) {
    if (this.serviceEndpoints == null) {this.serviceEndpoints = new ArrayList<PowerVSServiceEndpointBuilder>();}
    PowerVSServiceEndpointBuilder builder = new PowerVSServiceEndpointBuilder(item);
    if (index < 0 || index >= serviceEndpoints.size()) { _visitables.get("serviceEndpoints").add(builder); serviceEndpoints.add(builder); } else { _visitables.get("serviceEndpoints").add(index, builder); serviceEndpoints.add(index, builder);}
    return (A)this;
  }
  public A setToServiceEndpoints(int index,PowerVSServiceEndpoint item) {
    if (this.serviceEndpoints == null) {this.serviceEndpoints = new ArrayList<PowerVSServiceEndpointBuilder>();}
    PowerVSServiceEndpointBuilder builder = new PowerVSServiceEndpointBuilder(item);
    if (index < 0 || index >= serviceEndpoints.size()) { _visitables.get("serviceEndpoints").add(builder); serviceEndpoints.add(builder); } else { _visitables.get("serviceEndpoints").set(index, builder); serviceEndpoints.set(index, builder);}
    return (A)this;
  }
  public A addToServiceEndpoints(io.fabric8.openshift.api.model.config.v1.PowerVSServiceEndpoint... items) {
    if (this.serviceEndpoints == null) {this.serviceEndpoints = new ArrayList<PowerVSServiceEndpointBuilder>();}
    for (PowerVSServiceEndpoint item : items) {PowerVSServiceEndpointBuilder builder = new PowerVSServiceEndpointBuilder(item);_visitables.get("serviceEndpoints").add(builder);this.serviceEndpoints.add(builder);} return (A)this;
  }
  public A addAllToServiceEndpoints(Collection<PowerVSServiceEndpoint> items) {
    if (this.serviceEndpoints == null) {this.serviceEndpoints = new ArrayList<PowerVSServiceEndpointBuilder>();}
    for (PowerVSServiceEndpoint item : items) {PowerVSServiceEndpointBuilder builder = new PowerVSServiceEndpointBuilder(item);_visitables.get("serviceEndpoints").add(builder);this.serviceEndpoints.add(builder);} return (A)this;
  }
  public A removeFromServiceEndpoints(io.fabric8.openshift.api.model.config.v1.PowerVSServiceEndpoint... items) {
    for (PowerVSServiceEndpoint item : items) {PowerVSServiceEndpointBuilder builder = new PowerVSServiceEndpointBuilder(item);_visitables.get("serviceEndpoints").remove(builder);if (this.serviceEndpoints != null) {this.serviceEndpoints.remove(builder);}} return (A)this;
  }
  public A removeAllFromServiceEndpoints(Collection<PowerVSServiceEndpoint> items) {
    for (PowerVSServiceEndpoint item : items) {PowerVSServiceEndpointBuilder builder = new PowerVSServiceEndpointBuilder(item);_visitables.get("serviceEndpoints").remove(builder);if (this.serviceEndpoints != null) {this.serviceEndpoints.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromServiceEndpoints(Predicate<PowerVSServiceEndpointBuilder> predicate) {
    if (serviceEndpoints == null) return (A) this;
    final Iterator<PowerVSServiceEndpointBuilder> each = serviceEndpoints.iterator();
    final List visitables = _visitables.get("serviceEndpoints");
    while (each.hasNext()) {
      PowerVSServiceEndpointBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildServiceEndpoints instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<PowerVSServiceEndpoint> getServiceEndpoints() {
    return serviceEndpoints != null ? build(serviceEndpoints) : null;
  }
  public List<PowerVSServiceEndpoint> buildServiceEndpoints() {
    return serviceEndpoints != null ? build(serviceEndpoints) : null;
  }
  public PowerVSServiceEndpoint buildServiceEndpoint(int index) {
    return this.serviceEndpoints.get(index).build();
  }
  public PowerVSServiceEndpoint buildFirstServiceEndpoint() {
    return this.serviceEndpoints.get(0).build();
  }
  public PowerVSServiceEndpoint buildLastServiceEndpoint() {
    return this.serviceEndpoints.get(serviceEndpoints.size() - 1).build();
  }
  public PowerVSServiceEndpoint buildMatchingServiceEndpoint(Predicate<PowerVSServiceEndpointBuilder> predicate) {
    for (PowerVSServiceEndpointBuilder item: serviceEndpoints) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingServiceEndpoint(Predicate<PowerVSServiceEndpointBuilder> predicate) {
    for (PowerVSServiceEndpointBuilder item: serviceEndpoints) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withServiceEndpoints(List<PowerVSServiceEndpoint> serviceEndpoints) {
    if (this.serviceEndpoints != null) { _visitables.get("serviceEndpoints").clear();}
    if (serviceEndpoints != null) {this.serviceEndpoints = new ArrayList(); for (PowerVSServiceEndpoint item : serviceEndpoints){this.addToServiceEndpoints(item);}} else { this.serviceEndpoints = null;} return (A) this;
  }
  public A withServiceEndpoints(io.fabric8.openshift.api.model.config.v1.PowerVSServiceEndpoint... serviceEndpoints) {
    if (this.serviceEndpoints != null) {this.serviceEndpoints.clear(); _visitables.remove("serviceEndpoints"); }
    if (serviceEndpoints != null) {for (PowerVSServiceEndpoint item :serviceEndpoints){ this.addToServiceEndpoints(item);}} return (A) this;
  }
  public Boolean hasServiceEndpoints() {
    return serviceEndpoints != null && !serviceEndpoints.isEmpty();
  }
  public A addNewServiceEndpoint(String name,String url) {
    return (A)addToServiceEndpoints(new PowerVSServiceEndpoint(name, url));
  }
  public PowerVSPlatformStatusFluentImpl.ServiceEndpointsNested<A> addNewServiceEndpoint() {
    return new PowerVSPlatformStatusFluentImpl.ServiceEndpointsNestedImpl();
  }
  public PowerVSPlatformStatusFluentImpl.ServiceEndpointsNested<A> addNewServiceEndpointLike(PowerVSServiceEndpoint item) {
    return new PowerVSPlatformStatusFluentImpl.ServiceEndpointsNestedImpl(-1, item);
  }
  public PowerVSPlatformStatusFluentImpl.ServiceEndpointsNested<A> setNewServiceEndpointLike(int index,PowerVSServiceEndpoint item) {
    return new PowerVSPlatformStatusFluentImpl.ServiceEndpointsNestedImpl(index, item);
  }
  public PowerVSPlatformStatusFluentImpl.ServiceEndpointsNested<A> editServiceEndpoint(int index) {
    if (serviceEndpoints.size() <= index) throw new RuntimeException("Can't edit serviceEndpoints. Index exceeds size.");
    return setNewServiceEndpointLike(index, buildServiceEndpoint(index));
  }
  public PowerVSPlatformStatusFluentImpl.ServiceEndpointsNested<A> editFirstServiceEndpoint() {
    if (serviceEndpoints.size() == 0) throw new RuntimeException("Can't edit first serviceEndpoints. The list is empty.");
    return setNewServiceEndpointLike(0, buildServiceEndpoint(0));
  }
  public PowerVSPlatformStatusFluentImpl.ServiceEndpointsNested<A> editLastServiceEndpoint() {
    int index = serviceEndpoints.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last serviceEndpoints. The list is empty.");
    return setNewServiceEndpointLike(index, buildServiceEndpoint(index));
  }
  public PowerVSPlatformStatusFluentImpl.ServiceEndpointsNested<A> editMatchingServiceEndpoint(Predicate<PowerVSServiceEndpointBuilder> predicate) {
    int index = -1;
    for (int i=0;i<serviceEndpoints.size();i++) { 
    if (predicate.test(serviceEndpoints.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching serviceEndpoints. No match found.");
    return setNewServiceEndpointLike(index, buildServiceEndpoint(index));
  }
  public String getZone() {
    return this.zone;
  }
  public A withZone(String zone) {
    this.zone=zone; return (A) this;
  }
  public Boolean hasZone() {
    return this.zone != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PowerVSPlatformStatusFluentImpl that = (PowerVSPlatformStatusFluentImpl) o;
    if (!java.util.Objects.equals(cisInstanceCRN, that.cisInstanceCRN)) return false;

    if (!java.util.Objects.equals(region, that.region)) return false;

    if (!java.util.Objects.equals(serviceEndpoints, that.serviceEndpoints)) return false;

    if (!java.util.Objects.equals(zone, that.zone)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(cisInstanceCRN,  region,  serviceEndpoints,  zone,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (cisInstanceCRN != null) { sb.append("cisInstanceCRN:"); sb.append(cisInstanceCRN + ","); }
    if (region != null) { sb.append("region:"); sb.append(region + ","); }
    if (serviceEndpoints != null) { sb.append("serviceEndpoints:"); sb.append(serviceEndpoints + ","); }
    if (zone != null) { sb.append("zone:"); sb.append(zone + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ServiceEndpointsNestedImpl<N> extends PowerVSServiceEndpointFluentImpl<PowerVSPlatformStatusFluentImpl.ServiceEndpointsNested<N>> implements PowerVSPlatformStatusFluentImpl.ServiceEndpointsNested<N>,Nested<N>{
    ServiceEndpointsNestedImpl(int index,PowerVSServiceEndpoint item) {
      this.index = index;
      this.builder = new PowerVSServiceEndpointBuilder(this, item);
    }
    ServiceEndpointsNestedImpl() {
      this.index = -1;
      this.builder = new PowerVSServiceEndpointBuilder(this);
    }
    PowerVSServiceEndpointBuilder builder;
    int index;
    public N and() {
      return (N) PowerVSPlatformStatusFluentImpl.this.setToServiceEndpoints(index,builder.build());
    }
    public N endServiceEndpoint() {
      return and();
    }
    
  }
  
}
